Learn R Programming

emil (version 2.2.3)

fit_glmnet: Fit elastic net, LASSO or ridge regression model

Description

Using the glmnet package implementation.

Usage

fit_glmnet(x, y, family, nfolds, foldid, alpha = 1, lambda = NULL, ...)

fit_ridge_regression(...)

fit_lasso(...)

Arguments

Value

Fitted elastic net model.

Details

The alpha parameter of glmnet controls the type of penalty. Use 0 (default) for lasso only, 1 for ridge only, or an intermediate for a combination. This is typically the parameter to tune on. The shrinkage, controlled by the lambda parameter, can be left unspecified for internal tuning (works the same way as fit_glmnet).

See Also

emil, predict_glmnet, importance_glmnet, modeling_procedure