Learn R Programming

emil (version 2.2.3)

fit_pamr: Fit nearest shrunken centroids model.

Description

Wrapped version of the pamr package implementation. Note that this function uses internal cross-validation for determining the value of the shrinkage threshold.

Usage

fit_pamr(x, y, error_fun, cv, nfold, threshold = NULL, ...,
  thres_fun = function(thr, err) median(thr[err == min(err)]), slim = FALSE)

Arguments

x
Dataset, numerical matrix with observations as rows.
y
Class labels, factor.
error_fun
Error function for tuning.
cv
Cross-validation scheme for shrinkage tuning. It should be supplied on one of the following forms:

Value

  • Fitted pamr classifier.

item

  • nfold
  • threshold
  • ...
  • thres_fun
  • slim

code

cv$cv.objects

See Also

emil, predict_pamr, importance_pamr, modeling_procedure