Learn R Programming

emil (version 2.2.3)

index_fit: Convert a fold to row indexes of fittdng or test set

Description

Convert a fold to row indexes of fittdng or test set

Usage

index_fit(fold, allow_oversample = TRUE)

index_test(fold)

Arguments

Value

An integer vector of row indexes.

See Also

emil, resample