importance_pamr: Feature importance of nearest shrunken centroids.
Description
Calculated as the absolute difference between the overall centroid and a
class-wise shrunken centroid (which is the same for both classes except sign).Usage
importance_pamr(object, threshold, thres_fun = max, ...)
Value
A data frame of feature importance scores.Details
In case multiple thresholds give the same error the largest one is chosen
(i.e. the one keeping the fewest features).