Learn R Programming

emil (version 2.0.2)

importance_pamr: Feature importance of nearest shrunken centroids.

Description

Calculated as the absolute difference between the overall centroid and a class-wise shrunken centroid (which is the same for both classes except sign).

Usage

importance_pamr(object, threshold, thres_fun = max, ...)

Arguments

object
Fitted pamr classifier
threshold
Threshold to use for classification. This argument is only needed if you want to override the value set during model fitting.
thres_fun
Threshold selection function. Only needed if you want to override the function set during model fitting.
...
Sent to pamr.predict.

Value

  • A data frame of feature importance scores.

Details

In case multiple thresholds give the same error the largest one is chosen (i.e. the one keeping the fewest features).

See Also

emil, fit_pamr, predict_pamr, modeling_procedure