pre_pamr: PAMR adapted dataset pre-processing
Description
The predict framework is designed to work with dataset where rows correspond
to observations and columns to descriptors. PAMR wants it the other way, and
also to have the fitting set response vector supplied in a list with the
descriptors. This function applies a standard pre-processing function and
then reformats the result to satisfy PAMR.Value
A list with fitting and testing sets, formatted the way pamr wants
them.Details
pre_pamr must be run last if chained with other pre-processing
functions, since it substantially reshapes the data.